@@ -155,7 +155,7 @@ class _StandardResponse(DefaultModel):
                 }
             ]
         }
-        json_encoders = {type(DOC_ID.__supertype__): lambda x: str(x)}
+        json_encoders = {type(DOC_ID.__supertype__()): lambda x: str(x)}
         orm_mode = True
         allow_population_by_field_name = True
         alias_generator = partial(snake2camel, start_lower=True)
